==> haskell-uri-encode-1.5.0.5-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-uri-encode.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: uri-encode
version: 1.5.0.5
id: uri-encode-1.5.0.5-5lmv4lJBmTg9FoXsxBLeaK
key: uri-encode-1.5.0.5-5lmv4lJBmTg9FoXsxBLeaK
license: BSD3
maintainer: code@silk.co
synopsis: Unicode aware uri-encoding.
description:
    Unicode aware uri-encoding.
category: Network, Web
author: Silk
exposed: True
indefinite: False
exposed-modules:
    Network.URI.Encode
abi: 31018500a1e3f4e685ca75b0d8cebbd1
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/uri-encode-1.5.0.5
library-dirs: /usr/lib/ghc-8.2.2/site-local/uri-encode-1.5.0.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/uri-encode-1.5.0.5
hs-libraries: HSuri-encode-1.5.0.5-5lmv4lJBmTg9FoXsxBLeaK
depends:
    base-4.10.1.0 bytestring-0.10.8.2
    text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj
    utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO
    network-uri-2.6.1.0-LYYrYvUJy87zSaoB2hpvT
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj=168216a11cdc39c8cc50d80b9c45a385
             utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO=e0ce70380190fd366eaf58242d407bf1
             network-uri-2.6.1.0-LYYrYvUJy87zSaoB2hpvT=eb2c71a3c16909d5272749b4cd94d59c
haddock-interfaces: /usr/share/doc/haskell-uri-encode/html/uri-encode.haddock
haddock-html: /usr/share/doc/haskell-uri-encode/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-uri-encode-1.5.0.5-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-uri-encode.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: uri-encode
version: 1.5.0.5
id: uri-encode-1.5.0.5-5Catwi4SdqWKkVHjt2pJ5W
key: uri-encode-1.5.0.5-5Catwi4SdqWKkVHjt2pJ5W
license: BSD3
maintainer: code@silk.co
synopsis: Unicode aware uri-encoding.
description:
    Unicode aware uri-encoding.
category: Network, Web
author: Silk
exposed: True
indefinite: False
exposed-modules:
    Network.URI.Encode
abi: 65ae51b99cff419ce5f111ecbd4531fb
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/uri-encode-1.5.0.5
library-dirs: /usr/lib/ghc-8.2.2/site-local/uri-encode-1.5.0.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/uri-encode-1.5.0.5
hs-libraries: HSuri-encode-1.5.0.5-5Catwi4SdqWKkVHjt2pJ5W
depends:
    base-4.10.1.0 bytestring-0.10.8.2
    text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj
    utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO
    network-uri-2.6.1.0-BbYfQUrqmQG8TYLVq3Shq8
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=0c99dc42f18da90e6080c205f57d188a
             utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO=e0ce70380190fd366eaf58242d407bf1
             network-uri-2.6.1.0-BbYfQUrqmQG8TYLVq3Shq8=2a36153dc9687bb97652fb0d7269ad34
haddock-interfaces: /usr/share/doc/haskell-uri-encode/html/uri-encode.haddock
haddock-html: /usr/share/doc/haskell-uri-encode/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
